@@ -16,7 +16,8 @@ L.Map.mergeOptions({
     default_weight: 3,
     default_iconClass: 'Default',
     default_zoomTo: 16,
-    attributionControl: true,
+    default_popupContentTemplate: '# {name}\n{description}',
+    attributionControl: false,
     allowEdit: true,
     homeControl: true,
     zoomControl: true,
@@ -42,7 +43,8 @@ L.Map.mergeOptions({
     ],
     moreControl: true,
     captionBar: false,
-    slideshow: {}
+    slideshow: {},
+    clickable: true
 });
 
 L.Storage.Map.include({
@@ -317,6 +319,7 @@ L.Storage.Map.include({
         if (this.options.scaleControl) {
             this._controls.scaleControl = L.control.scale().addTo(this);
         }
+        this._controls.attribution = new L.S.AttributionControl().addTo(this);
         if (this.options.miniMap) {
             this.whenReady(function () {
                 if (this.selected_tilelayer) {
@@ -325,6 +328,11 @@ L.Storage.Map.include({
                 }
             });
         }
+        if (this.options.scrollWheelZoom) {
+            this.scrollWheelZoom.enable();
+        } else {
+            this.scrollWheelZoom.disable();
+        }
 
     },
 
@@ -751,15 +759,16 @@ L.Storage.Map.include({
         });
         var creditsContainer = L.DomUtil.create('div', 'credits-container', container),
             credits = L.DomUtil.createFieldset(creditsContainer, L._('Credits'));
-        title = L.DomUtil.create('h5', '', credits);
-        title.innerHTML = L._('User content credits');
-        var contentCredit = L.DomUtil.create('p', '', credits),
-            licence = L.DomUtil.create('a', '', contentCredit);
+        title = L.DomUtil.add('h5', '', credits, L._('User content credits'));
+        if (this.options.shortCredit || this.options.longCredit) {
+            L.DomUtil.add('p', '', credits, L.Util.toHTML(this.options.longCredit || this.options.shortCredit));
+        }
         if (this.options.licence) {
-            licence.innerHTML = this.options.licence.name;
-            licence.href = this.options.licence.url;
-            contentCredit.innerHTML =  L._('Map user content has been published under licence')
-                                       + ' ' + contentCredit.innerHTML;
+            var licence = L.DomUtil.add('p', '', credits, L._('Map user content has been published under licence') + ' '),
+                link = L.DomUtil.add('a', '', licence, this.options.licence.name);
+            link.href = this.options.licence.url;
+        } else {
+            L.DomUtil.add('p', '', credits, L._('No licence has been set'));
         }
         L.DomUtil.create('hr', '', credits);
         title = L.DomUtil.create('h5', '', credits);
@@ -865,11 +874,14 @@ L.Storage.Map.include({
             'fillOpacity',
             'dashArray',
             'popupTemplate',
+            'popupContentTemplate',
             'zoomTo',
             'captionBar',
             'slideshow',
             'sortKey',
-            'showLabel'
+            'showLabel',
+            'shortCredit',
+            'longCredit'
         ], properties = {};
         for (var i = editableOptions.length - 1; i >= 0; i--) {
             if (typeof this.options[editableOptions[i]] !== 'undefined') {
@@ -938,7 +950,7 @@ L.Storage.Map.include({
             this.addLayer(datalayer.layer);
             return datalayer;
         }
-        return new L.S.DataLayer(this, {});
+        return this._createDataLayer({});
     },
 
     getDataLayerByStorageId: function (storage_id) {
@@ -958,8 +970,7 @@ L.Storage.Map.include({
         var container = L.DomUtil.create('div'),
             metadataFields = [
                 'options.name',
-                'options.description',
-                ['options.licence', {handler: 'LicenceChooser', label: L._('licence')}]
+                'options.description'
             ],
             title = L.DomUtil.create('h4', '', container);
         title.innerHTML = L._('Edit map properties');
@@ -996,6 +1007,7 @@ L.Storage.Map.include({
             'options.fillOpacity',
             'options.dashArray',
             'options.popupTemplate',
+            'options.popupContentTemplate',
             'options.zoomTo',
             'options.showLabel',
             ['options.sortKey', {handler: 'Input', helpText: L._('Property to use for sorting features'), placeholder: L._('Default: name')}]
@@ -1046,6 +1058,19 @@ L.Storage.Map.include({
             callbackContext: this
         });
         limitBounds.appendChild(boundsBuilder.build());
+        var setCurrentButton = L.DomUtil.add('a', '', limitBounds, L._('Use current bounds'));
+        setCurrentButton.href = '#';
+        L.DomEvent.on(setCurrentButton, 'click', function () {
+            var bounds = this.getBounds();
+            this.options.limitBounds.south = L.Util.formatNum(bounds.getSouth());
+            this.options.limitBounds.west = L.Util.formatNum(bounds.getWest());
+            this.options.limitBounds.north = L.Util.formatNum(bounds.getNorth());
+            this.options.limitBounds.east = L.Util.formatNum(bounds.getEast());
+            boundsBuilder.fetchAll();
+            this.isDirty = true;
+            this.handleLimitBounds();
+        }, this);
+
         var slideshow = L.DomUtil.createFieldset(container, L._('Slideshow'));
         var slideshowFields = [
             ['options.slideshow.delay', {handler: 'IntInput', placeholder: L._('Set a value for adding a slideshow'), helpText: L._('Delay between elements (in milliseconds)')}],
@@ -1061,18 +1086,17 @@ L.Storage.Map.include({
         });
         slideshow.appendChild(slideshowBuilder.build());
 
-        var setCurrentButton = L.DomUtil.add('a', '', limitBounds, L._('Use current bounds'));
-        setCurrentButton.href = '#';
-        L.DomEvent.on(setCurrentButton, 'click', function () {
-            var bounds = this.getBounds();
-            this.options.limitBounds.south = L.Util.formatNum(bounds.getSouth());
-            this.options.limitBounds.west = L.Util.formatNum(bounds.getWest());
-            this.options.limitBounds.north = L.Util.formatNum(bounds.getNorth());
-            this.options.limitBounds.east = L.Util.formatNum(bounds.getEast());
-            boundsBuilder.fetchAll();
-            this.isDirty = true;
-            this.handleLimitBounds();
-        }, this);
+        var credits = L.DomUtil.createFieldset(container, L._('Credits'));
+        var creditsFields = [
+            ['options.licence', {handler: 'LicenceChooser', label: L._('licence')}],
+            ['options.shortCredit', {handler: 'Input', label: L._('Short credits'), helpText: L._('Will be displayed in the bottom right corner of the map'), helpEntries: 'textFormatting'}],
+            ['options.longCredit', {handler: 'Textarea', label: L._('Long credits'), helpText: L._('Will be visible in the caption of the map'), helpEntries: 'textFormatting'}]
+        ];
+        var creditsBuilder = new L.S.FormBuilder(this, creditsFields, {
+            callback: function () {this._controls.attribution._update();},
+            callbackContext: this
+        });
+        credits.appendChild(creditsBuilder.build());
 
         var advancedActions = L.DomUtil.createFieldset(container, L._('Advanced actions'));
         var del = L.DomUtil.create('a', 'storage-delete', advancedActions);
@@ -1129,7 +1153,7 @@ L.Storage.Map.include({
         L.bind(setName, this)();
         this.on('synced', L.bind(setName, this));
         this.onceDatalayersLoaded(function () {
-            container.appendChild(this.slideshow.renderToolbox());
+            this.slideshow.renderToolbox(container);
         });
     },
 
